@@ -1,11 +1,10 @@
 cr = "\n"
 
 s = "####################################################################" + cr
-s += "# FINANCEPY BETA Version " + str('0.201') + " - This build:  16 Jul 2021 at 18:38 #" + cr
+s += "# FINANCEPY BETA Version " + str('0.202') + " - This build:  16 Jul 2021 at 18:46 #" + cr
 s += "# **** NEW PEP8 COMPLIANT VERSION -- PLEASE UPDATE YOUR CODE  **** #" + cr
 s += "#      This software is distributed FREE & WITHOUT ANY WARRANTY    #" + cr
-s += "# For info and disclaimer - https://github.com/domokane/FinancePy  #" + cr
-s += "#      Send any bug reports or comments to quant@financepy.com     #" + cr
+s += "#  Report bugs as issues at https://github.com/domokane/FinancePy  #" + cr
 s += "####################################################################"
 s += cr
 
