@@ -72,20 +72,6 @@ class FXBarrierOption(FXOption):
         # by Clewlow, Llanos and Strickland December 1994 which can be found at
         # https://warwick.ac.uk/fac/soc/wbs/subjects/finance/research/wpaperseries/1994/94-54.pdf
 
-        if isinstance(valuation_date, Date) == False:
-            raise FinError("Valuation date is not a Date")
-
-        if valuation_date > self._expiry_date:
-            raise FinError("Valuation date after expiry date.")
-
-        if dom_discount_curve._valuation_date != valuation_date:
-            raise FinError(
-                "Domestic Curve valuation date not same as option valuation date")
-
-        if for_discount_curve._valuation_date != valuation_date:
-            raise FinError(
-                "Foreign Curve valuation date not same as option valuation date")
-
         K = self._strike_fx_rate
         S0 = spot_fx_rate
         h = self._barrier_level
@@ -166,85 +152,85 @@ class FXBarrierOption(FXOption):
         if self._option_type == FinFXBarrierTypes.DOWN_AND_OUT_CALL:
             if h >= K:
                 c_do = S0 * dq * N(x1) - K * df * N(x1 - sigmaRootT) \
-                    - S0 * dq * pow(hOverS, 2.0 * ll) * N(y1) \
-                    + K * df * pow(hOverS, 2.0 * ll - 2.0) * N(y1 - sigmaRootT)
+                       - S0 * dq * pow(hOverS, 2.0 * ll) * N(y1) \
+                       + K * df * pow(hOverS, 2.0 * ll - 2.0) * N(y1 - sigmaRootT)
                 price = c_do
             else:
                 c_di = S0 * dq * pow(hOverS, 2.0 * ll) * N(y) \
-                    - K * df * pow(hOverS, 2.0 * ll - 2.0) * N(y - sigmaRootT)
+                       - K * df * pow(hOverS, 2.0 * ll - 2.0) * N(y - sigmaRootT)
                 price = c - c_di
         elif self._option_type == FinFXBarrierTypes.DOWN_AND_IN_CALL:
             if h <= K:
                 c_di = S0 * dq * pow(hOverS, 2.0 * ll) * N(y) \
-                    - K * df * pow(hOverS, 2.0 * ll - 2.0) * N(y - sigmaRootT)
+                       - K * df * pow(hOverS, 2.0 * ll - 2.0) * N(y - sigmaRootT)
                 price = c_di
             else:
                 c_do = S0 * dq * N(x1) \
-                    - K * df * N(x1 - sigmaRootT) \
-                    - S0 * dq * pow(hOverS, 2.0 * ll) * N(y1) \
-                    + K * df * pow(hOverS, 2.0 * ll - 2.0) * N(y1 - sigmaRootT)
+                       - K * df * N(x1 - sigmaRootT) \
+                       - S0 * dq * pow(hOverS, 2.0 * ll) * N(y1) \
+                       + K * df * pow(hOverS, 2.0 * ll - 2.0) * N(y1 - sigmaRootT)
                 price = c - c_do
         elif self._option_type == FinFXBarrierTypes.UP_AND_IN_CALL:
             if h >= K:
                 c_ui = S0 * dq * N(x1) - K * df * N(x1 - sigmaRootT) \
-                    - S0 * dq * pow(hOverS, 2.0 * ll) * (N(-y) - N(-y1)) \
-                    + K * df * pow(hOverS, 2.0 * ll - 2.0) * \
-                    (N(-y + sigmaRootT) - N(-y1 + sigmaRootT))
+                       - S0 * dq * pow(hOverS, 2.0 * ll) * (N(-y) - N(-y1)) \
+                       + K * df * pow(hOverS, 2.0 * ll - 2.0) * \
+                       (N(-y + sigmaRootT) - N(-y1 + sigmaRootT))
                 price = c_ui
             else:
                 price = c
         elif self._option_type == FinFXBarrierTypes.UP_AND_OUT_CALL:
             if h > K:
                 c_ui = S0 * dq * N(x1) - K * df * N(x1 - sigmaRootT) \
-                    - S0 * dq * pow(hOverS, 2.0 * ll) * (N(-y) - N(-y1)) \
-                    + K * df * pow(hOverS, 2.0 * ll - 2.0) * \
-                    (N(-y + sigmaRootT) - N(-y1 + sigmaRootT))
+                       - S0 * dq * pow(hOverS, 2.0 * ll) * (N(-y) - N(-y1)) \
+                       + K * df * pow(hOverS, 2.0 * ll - 2.0) * \
+                       (N(-y + sigmaRootT) - N(-y1 + sigmaRootT))
                 price = c - c_ui
             else:
                 price = 0.0
         elif self._option_type == FinFXBarrierTypes.UP_AND_IN_PUT:
             if h > K:
                 p_ui = -S0 * dq * pow(hOverS, 2.0 * ll) * N(-y) \
-                    + K * df * pow(hOverS, 2.0 * ll - 2.0) * N(-y + sigmaRootT)
+                       + K * df * pow(hOverS, 2.0 * ll - 2.0) * N(-y + sigmaRootT)
                 price = p_ui
             else:
                 p_uo = -S0 * dq * N(-x1) \
-                    + K * df * N(-x1 + sigmaRootT) \
-                    + S0 * dq * pow(hOverS, 2.0 * ll) * N(-y1) \
+                       + K * df * N(-x1 + sigmaRootT) \
+                       + S0 * dq * pow(hOverS, 2.0 * ll) * N(-y1) \
                        - K * df * pow(hOverS, 2.0 * ll - 2.0) * \
-                    N(-y1 + sigmaRootT)
+                       N(-y1 + sigmaRootT)
                 price = p - p_uo
         elif self._option_type == FinFXBarrierTypes.UP_AND_OUT_PUT:
             if h >= K:
                 p_ui = -S0 * dq * pow(hOverS, 2.0 * ll) * N(-y) \
-                    + K * df * pow(hOverS, 2.0 * ll - 2.0) * N(-y + sigmaRootT)
+                       + K * df * pow(hOverS, 2.0 * ll - 2.0) * N(-y + sigmaRootT)
                 price = p - p_ui
             else:
                 p_uo = -S0 * dq * N(-x1) \
-                    + K * df * N(-x1 + sigmaRootT) \
-                    + S0 * dq * pow(hOverS, 2.0 * ll) * N(-y1) \
+                       + K * df * N(-x1 + sigmaRootT) \
+                       + S0 * dq * pow(hOverS, 2.0 * ll) * N(-y1) \
                        - K * df * pow(hOverS, 2.0 * ll - 2.0) * \
-                    N(-y1 + sigmaRootT)
+                       N(-y1 + sigmaRootT)
                 price = p_uo
         elif self._option_type == FinFXBarrierTypes.DOWN_AND_OUT_PUT:
             if h >= K:
                 price = 0.0
             else:
                 p_di = -S0 * dq * N(-x1) \
-                    + K * df * N(-x1 + sigmaRootT) \
-                    + S0 * dq * pow(hOverS, 2.0 * ll) * (N(y) - N(y1)) \
+                       + K * df * N(-x1 + sigmaRootT) \
+                       + S0 * dq * pow(hOverS, 2.0 * ll) * (N(y) - N(y1)) \
                        - K * df * pow(hOverS, 2.0 * ll - 2.0) * \
-                    (N(y - sigmaRootT) - N(y1 - sigmaRootT))
+                       (N(y - sigmaRootT) - N(y1 - sigmaRootT))
                 price = p - p_di
         elif self._option_type == FinFXBarrierTypes.DOWN_AND_IN_PUT:
             if h >= K:
                 price = p
             else:
                 p_di = -S0 * dq * N(-x1) \
-                    + K * df * N(-x1 + sigmaRootT) \
-                    + S0 * dq * pow(hOverS, 2.0 * ll) * (N(y) - N(y1)) \
+                       + K * df * N(-x1 + sigmaRootT) \
+                       + S0 * dq * pow(hOverS, 2.0 * ll) * (N(y) - N(y1)) \
                        - K * df * pow(hOverS, 2.0 * ll - 2.0) * \
-                    (N(y - sigmaRootT) - N(y1 - sigmaRootT))
+                       (N(y - sigmaRootT) - N(y1 - sigmaRootT))
                 price = p_di
         else:
             raise FinError("Unknown barrier option type." +
