@@ -15,7 +15,7 @@ from ...utils.date import Date
 from ...utils.helpers import label_to_string
 from ...utils.helpers import check_argument_types, _func_name
 from ...utils.global_vars import gDaysInYear
-from ...market.curves.interpolator import InterpTypes, Interpolator
+from ...market.curves.interpolator import InterpTypes, FinInterpolator
 from ...market.curves.discount_curve import DiscountCurve
 from ...products.rates.ibor_deposit import IborDeposit
 from ...products.rates.ibor_fra import IborFRA
@@ -351,12 +351,7 @@ class IborSingleCurve(DiscountCurve):
         self._usedDeposits = ibor_deposits
         self._usedFRAs = ibor_fras
         self._usedSwaps = ibor_swaps
-
-      # Need the floating leg basis for the curve
-        if len(self._usedSwaps) > 0:
-            self._day_count_type = ibor_swaps[0]._float_leg._day_count_type
-        else:
-            self._day_count_type = None
+        self._day_count_type = None
 
 ###############################################################################
 
@@ -366,7 +361,7 @@ class IborSingleCurve(DiscountCurve):
         of interpolation approaches between the swap rates and other rates. It
         involves the use of a solver. """
 
-        self._interpolator = Interpolator(self._interp_type)
+        self._interpolator = FinInterpolator(self._interp_type)
         self._times = np.array([])
         self._dfs = np.array([])
 
@@ -470,7 +465,7 @@ class IborSingleCurve(DiscountCurve):
         the linear swap rate method that is fast and exact as it does not
         require the use of a solver. It is also market standard. """
 
-        self._interpolator = Interpolator(self._interp_type)
+        self._interpolator = FinInterpolator(self._interp_type)
 
         self._times = np.array([])
         self._dfs = np.array([])
