@@ -2,24 +2,27 @@
 # Copyright (C) 2018, 2019, 2020 Dominic O'Kane
 ###############################################################################
 
-import matplotlib.pyplot as plt
-import time
-import numpy as np
-from financepy.utils.global_types import FinExerciseTypes
-from financepy.utils.global_vars import gDaysInYear
-from financepy.utils.date import Date
-from financepy.market.curves.discount_curve import DiscountCurve
-from financepy.market.curves.discount_curve_flat import DiscountCurveFlat
-from financepy.products.bonds.bond import Bond
-from financepy.utils.frequency import FrequencyTypes
-from financepy.utils.day_count import DayCountTypes
-from financepy.products.bonds.bond_option import BondOption
-from financepy.utils.global_types import OptionTypes
-from financepy.models.hw_tree import HWTree, FinHWEuropeanCalcType
-from FinTestCases import FinTestCases, globalTestCaseMode
 import sys
 sys.path.append("..\\")
 
+from FinTestCases import FinTestCases, globalTestCaseMode
+from financepy.models.hw_tree import HWTree, FinHWEuropeanCalcType
+from financepy.utils.global_types import FinOptionTypes
+from financepy.products.bonds.bond_option import BondOption
+from financepy.utils.day_count import DayCountTypes
+from financepy.utils.frequency import FrequencyTypes
+from financepy.products.bonds.bond import Bond
+from financepy.market.curves.discount_curve_flat import DiscountCurveFlat
+from financepy.market.curves.discount_curve import DiscountCurve
+from financepy.utils.date import Date
+from financepy.utils.global_vars import gDaysInYear
+from financepy.utils.global_types import FinExerciseTypes
+
+import numpy as np
+import time
+import matplotlib.pyplot as plt
+
+
 
 testCases = FinTestCases(__file__, globalTestCaseMode)
 
@@ -51,7 +54,7 @@ def test_BondOption():
 
     strikes = [80, 85, 90, 95, 100, 105, 110, 115, 120]
 
-    option_type = OptionTypes.EUROPEAN_CALL
+    option_type = FinOptionTypes.EUROPEAN_CALL
 
     testCases.header("LABEL", "VALUE")
 
@@ -78,7 +81,7 @@ def test_BondOption():
 
     ###########################################################################
 
-    option_type = OptionTypes.AMERICAN_CALL
+    option_type = FinOptionTypes.AMERICAN_CALL
 
     price = bond.clean_price_from_discount_curve(
         settlement_date, discount_curve)
@@ -102,7 +105,7 @@ def test_BondOption():
 
     ###########################################################################
 
-    option_type = OptionTypes.EUROPEAN_PUT
+    option_type = FinOptionTypes.EUROPEAN_PUT
     testCases.banner("HW EUROPEAN PUT")
     testCases.header("STRIKE", "VALUE")
 
@@ -123,7 +126,7 @@ def test_BondOption():
 
     ###########################################################################
 
-    option_type = OptionTypes.AMERICAN_PUT
+    option_type = FinOptionTypes.AMERICAN_PUT
     testCases.banner("HW AMERICAN PUT")
     testCases.header("STRIKE", "VALUE")
 
@@ -181,7 +184,7 @@ def test_BondOptionEuropeanConvergence():
         a = 0.1
 
         start = time.time()
-        option_type = OptionTypes.EUROPEAN_PUT
+        option_type = FinOptionTypes.EUROPEAN_PUT
 
         bond_option1 = BondOption(bond, expiry_date, strike_price, face,
                                   option_type)
@@ -195,7 +198,7 @@ def test_BondOptionEuropeanConvergence():
                         FinHWEuropeanCalcType.EXPIRY_ONLY)
         v2put = bond_option2.value(settlement_date, discount_curve, model2)
 
-        option_type = OptionTypes.EUROPEAN_CALL
+        option_type = FinOptionTypes.EUROPEAN_CALL
 
         bond_option1 = BondOption(bond, expiry_date, strike_price, face,
                                   option_type)
@@ -248,14 +251,14 @@ def test_BondOptionAmericanConvergenceONE():
 
         start = time.time()
 
-        option_type = OptionTypes.AMERICAN_PUT
+        option_type = FinOptionTypes.AMERICAN_PUT
         bond_option1 = BondOption(bond, expiry_date, strike_price, face,
                                   option_type)
 
         model1 = HWTree(sigma, a, num_time_steps)
         v1put = bond_option1.value(settlement_date, discount_curve, model1)
 
-        option_type = OptionTypes.EUROPEAN_PUT
+        option_type = FinOptionTypes.EUROPEAN_PUT
         bond_option2 = BondOption(bond, expiry_date, strike_price, face,
                                   option_type)
 
@@ -263,14 +266,14 @@ def test_BondOptionAmericanConvergenceONE():
                         FinHWEuropeanCalcType.EXPIRY_ONLY)
         v2put = bond_option2.value(settlement_date, discount_curve, model2)
 
-        option_type = OptionTypes.AMERICAN_CALL
+        option_type = FinOptionTypes.AMERICAN_CALL
         bond_option1 = BondOption(bond, expiry_date, strike_price, face,
                                   option_type)
 
         model1 = HWTree(sigma, a, num_time_steps)
         v1call = bond_option1.value(settlement_date, discount_curve, model1)
 
-        option_type = OptionTypes.EUROPEAN_CALL
+        option_type = FinOptionTypes.EUROPEAN_CALL
         bond_option2 = BondOption(bond, expiry_date, strike_price, face,
                                   option_type)
 
@@ -329,25 +332,25 @@ def test_BondOptionAmericanConvergenceTWO():
         start = time.time()
 
         europeanCallBondOption = BondOption(bond, expiry_date, K, face,
-                                            OptionTypes.EUROPEAN_CALL)
+                                            FinOptionTypes.EUROPEAN_CALL)
 
         v_ec = europeanCallBondOption.value(settlement_date, discount_curve,
                                             hwModel)
 
         americanCallBondOption = BondOption(bond, expiry_date, K, face,
-                                            OptionTypes.AMERICAN_CALL)
+                                            FinOptionTypes.AMERICAN_CALL)
 
         v_ac = americanCallBondOption.value(settlement_date, discount_curve,
                                             hwModel)
 
         europeanPutBondOption = BondOption(bond, expiry_date, K, face,
-                                           OptionTypes.EUROPEAN_PUT)
+                                           FinOptionTypes.EUROPEAN_PUT)
 
         v_ep = europeanPutBondOption.value(settlement_date, discount_curve,
                                            hwModel)
 
         americanPutBondOption = BondOption(bond, expiry_date, K, face,
-                                           OptionTypes.AMERICAN_PUT)
+                                           FinOptionTypes.AMERICAN_PUT)
 
         v_ap = americanPutBondOption.value(settlement_date, discount_curve,
                                            hwModel)
@@ -425,22 +428,22 @@ def test_BondOptionZEROVOLConvergence():
             a = 0.1
             model = HWTree(sigma, a, num_steps)
 
-            option_type = OptionTypes.EUROPEAN_CALL
+            option_type = FinOptionTypes.EUROPEAN_CALL
             bond_option1 = BondOption(
                 bond, expiry_date, strike_price, face, option_type)
             v1 = bond_option1.value(settlement_date, discount_curve, model)
 
-            option_type = OptionTypes.AMERICAN_CALL
+            option_type = FinOptionTypes.AMERICAN_CALL
             bond_option2 = BondOption(
                 bond, expiry_date, strike_price, face, option_type)
             v2 = bond_option2.value(settlement_date, discount_curve, model)
 
-            option_type = OptionTypes.EUROPEAN_PUT
+            option_type = FinOptionTypes.EUROPEAN_PUT
             bond_option3 = BondOption(
                 bond, expiry_date, strike_price, face, option_type)
             v3 = bond_option3.value(settlement_date, discount_curve, model)
 
-            option_type = OptionTypes.AMERICAN_PUT
+            option_type = FinOptionTypes.AMERICAN_PUT
             bond_option4 = BondOption(
                 bond, expiry_date, strike_price, face, option_type)
             v4 = bond_option4.value(settlement_date, discount_curve, model)
@@ -451,18 +454,16 @@ def test_BondOptionZEROVOLConvergence():
 
 ###############################################################################
 
-
 def test_BondOptionDerivaGem():
 
     # See https://github.com/domokane/FinancePy/issues/98
-
+    
     settlement_date = Date(1, 12, 2019)
 
     rate = 0.05
     dcType = DayCountTypes.THIRTY_360_BOND
     fixedFreq = FrequencyTypes.SEMI_ANNUAL
-    discount_curve = DiscountCurveFlat(
-        settlement_date, rate, fixedFreq, dcType)
+    discount_curve = DiscountCurveFlat(settlement_date, rate, fixedFreq, dcType)
 
     issue_date = Date(1, 12, 2018)
     expiry_date = settlement_date.add_tenor("18m")
@@ -475,14 +476,14 @@ def test_BondOptionDerivaGem():
     strike_price = 100.0
     face = 100.0
 
-    europeanCallBondOption = BondOption(bond, expiry_date, strike_price, face,
-                                        OptionTypes.EUROPEAN_CALL)
+    europeanCallBondOption = BondOption(bond, expiry_date, strike_price, face, 
+                                        FinOptionTypes.EUROPEAN_CALL)
     cp = bond.clean_price_from_discount_curve(expiry_date, discount_curve)
     fp = bond.full_price_from_discount_curve(expiry_date, discount_curve)
 #    print("Fixed Income Clean Price: %9.3f"% cp)
 #    print("Fixed Income Full  Price: %9.3f"% fp)
 
-    num_steps = 500
+    num_steps= 500
     sigma = 0.0125
     a = 0.1
     modelHW = HWTree(sigma, a, num_steps)
@@ -502,12 +503,12 @@ def test_BondOptionDerivaGem():
         ncd = bond._flow_dates[i]
 
         if ncd > settlement_date:
-
+            
             if len(couponTimes) == 0:
                 flowTime = (pcd - settlement_date) / gDaysInYear
                 couponTimes.append(flowTime)
                 couponFlows.append(cpn)
-
+                
             flowTime = (ncd - settlement_date) / gDaysInYear
             couponTimes.append(flowTime)
             couponFlows.append(cpn)
@@ -532,7 +533,7 @@ def test_BondOptionDerivaGem():
                                                  couponTimes, couponFlows,
                                                  times, dfs)
     # print("Jamshidian:", vjam)
-
+    
     model._num_time_steps = 100
     model.build_tree(tmat, times, dfs)
     exerciseType = FinExerciseTypes.EUROPEAN
